//
//  ContactViewController.m
//  ETSINF-UPV
//
//  Created by Alberto Saez on 05/08/13.
//  Copyright (c) 2013 Alberto Saez. All rights reserved.
//

#import "ContactViewController.h"

NSString * const etsinfUpvSchedulePrefKey = @"etsinfUpvSchedulePrefKey";
NSString * const etsinfUpvDatePrefKey = @"etsinfUpvDatePrefKey";

@implementation ContactViewController
@synthesize scheduleWebView, activityIndicator, scheduleOfflineText, updateLabel;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
//        [[self tabBarItem] setTitle:@"Contact"];
        [[self tabBarItem] setImage:[UIImage imageNamed:@"contact.png"]];
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    [scheduleWebView setDelegate:self];
    [scheduleWebView setUserInteractionEnabled:NO];
    [scheduleWebView autoresizesSubviews];
    scheduleWebView.autoresizingMask=(UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth);
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    [scheduleOfflineText setHidden:YES];
    [scheduleWebView loadRequest:[NSURLRequest requestWithURL:[NSURL URLWithString:@"http://172.20.10.2"]]];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (IBAction)sendMail
{
    if ([MFMailComposeViewController canSendMail])
    {
        MFMailComposeViewController *mailer = [[MFMailComposeViewController alloc] init];
        mailer.mailComposeDelegate = self;
        [mailer setSubject:@"A Message from the ETSINF-UPV app"];
        NSArray *toRecipients = [NSArray arrayWithObjects:@"int_inf@upvnet.upv.es", nil];
        [mailer setToRecipients:toRecipients];
        [self presentViewController:mailer animated:YES completion:nil];
    }
    else
    {
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:NSLocalizedString(@"Failure",@"")
                                                        message:NSLocalizedString(@"Your device doesn't support the composer sheet",@"")
                                                       delegate:nil
                                              cancelButtonTitle:@"OK"
                                              otherButtonTitles:nil];
        [alert show];
    }
}

- (IBAction)showTwitter:(id)sender
{
    NSURL *url = [NSURL URLWithString:@"http://www.twitter.com/etsinfupv"];
    
    if (![[UIApplication sharedApplication] openURL:url])
        NSLog(@"%@%@",@"Failed to open url:",[url description]);
}

- (IBAction)showFacebook:(id)sender
{
    NSURL *url = [NSURL URLWithString:@"http://www.facebook.com/pages/Valencia-Spain/Escuela-Tecnica-Superior-de-Ingenieria-Informatica/125745612619"];
    
    if (![[UIApplication sharedApplication] openURL:url])
        NSLog(@"%@%@",@"Failed to open url:",[url description]);
}

- (IBAction)showBlog:(id)sender
{
    NSURL *url = [NSURL URLWithString:@"http://www.intacadetsinf.blogs.upv.es"];
    
    if (![[UIApplication sharedApplication] openURL:url])
        NSLog(@"%@%@",@"Failed to open url:",[url description]);
}

- (void)mailComposeController:(MFMailComposeViewController*)controller didFinishWithResult:(MFMailComposeResult)result error:(NSError*)error
{
    switch (result)
    {
        case MFMailComposeResultCancelled:
            NSLog(@"Mail cancelled: you cancelled the operation and no email message was queued.");
            break;
        case MFMailComposeResultSaved:
            NSLog(@"Mail saved: you saved the email message in the drafts folder.");
            break;
        case MFMailComposeResultSent:
            NSLog(@"Mail send: the email message is queued in the outbox. It is ready to send.");
            break;
        case MFMailComposeResultFailed:
            NSLog(@"Mail failed: the email message was not saved or queued, possibly due to an error.");
            break;
        default:
            NSLog(@"Mail not sent.");
            break;
    }
    // Remove the mail view
    [self dismissViewControllerAnimated:YES completion:nil];
}

- (void)webView:(UIWebView *)webView didFailLoadWithError:(NSError *)error
{
    [activityIndicator stopAnimating];
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:NSLocalizedString(@"Failure",@"")
                                                    message:NSLocalizedString(@"Your device has internet connection?",@"")
                                                   delegate:nil
                                          cancelButtonTitle:@"OK"
                                          otherButtonTitles:nil];
    [alert show];
    NSString *savedText = [[NSUserDefaults standardUserDefaults] objectForKey:etsinfUpvSchedulePrefKey];
    if (savedText) {
        [scheduleOfflineText setText:savedText];
        NSDateFormatter *formatter = [[NSDateFormatter alloc] init];
        [formatter setDateStyle:NSDateFormatterShortStyle];
        [formatter setTimeStyle:NSDateFormatterNoStyle];
        NSDate *date = [[NSUserDefaults standardUserDefaults] objectForKey:etsinfUpvDatePrefKey];
        NSString *update = NSLocalizedString(@"Last update", @"");
        [updateLabel setText:[NSString stringWithFormat:@"%@: %@", update, [formatter stringFromDate:date]]];

    }
    [scheduleOfflineText setHidden:NO];
}

- (void)webViewDidStartLoad:(UIWebView *)webView
{
    [activityIndicator startAnimating];
}

- (void)webViewDidFinishLoad:(UIWebView *)webView
{
    [activityIndicator stopAnimating];
    
    NSDateFormatter *formatter = [[NSDateFormatter alloc] init];
    [formatter setDateStyle:NSDateFormatterShortStyle];
    [formatter setTimeStyle:NSDateFormatterNoStyle];
    NSDate *date = [NSDate date];
    NSString *update = NSLocalizedString(@"Last update", @"");
    [updateLabel setText:[NSString stringWithFormat:@"%@: %@", update, [formatter stringFromDate:date]]];
    NSString *downloadedInfo = [scheduleWebView stringByEvaluatingJavaScriptFromString: @"document.body.innerHTML"];
    [[NSUserDefaults standardUserDefaults] setObject:downloadedInfo forKey:etsinfUpvSchedulePrefKey];
    [[NSUserDefaults standardUserDefaults] setObject:date forKey:etsinfUpvDatePrefKey];
    
}

@end
