//
//  MapViewController.m
//  ETSINF-UPV
//
//  Created by Alberto Saez on 03/08/13.
//  Copyright (c) 2013 Alberto Saez. All rights reserved.
//

#import "MapViewController.h"

NSString * const etsinfUpvMapTypePrefKey = @"etsinfUpvMapTypePrefKey";
NSString * const etsinfUpvMapRegionPrefKey = @"etsinfUpvMapRegionPrefKey";


@implementation MapViewController

- (void)makeMapAnnotations
{
    MKPointAnnotation *internationalPoint = [[MKPointAnnotation alloc] init];
    internationalPoint.coordinate = CLLocationCoordinate2DMake(39.482924,-0.346923);
    internationalPoint.title = NSLocalizedString(@"International Office",@"");
    internationalPoint.subtitle = NSLocalizedString(@"Building 1G",@"");
    [EtsinfMapView addAnnotation:internationalPoint];
    
    MKPointAnnotation *libraryPoint = [[MKPointAnnotation alloc] init];
    libraryPoint.coordinate = CLLocationCoordinate2DMake(39.482794,-0.347776);
    libraryPoint.title = NSLocalizedString(@"Library",@"");
    libraryPoint.subtitle = NSLocalizedString(@"Building 1H",@"");
    [EtsinfMapView addAnnotation:libraryPoint];
    
    MKPointAnnotation *vellaPoint = [[MKPointAnnotation alloc] init];
    vellaPoint.coordinate = CLLocationCoordinate2DMake(39.482307,-0.348575);
    vellaPoint.title = NSLocalizedString(@"Vella coffe",@"");
    vellaPoint.subtitle = NSLocalizedString(@"Building 1B",@"");
    [EtsinfMapView addAnnotation:vellaPoint];
    
    MKPointAnnotation *reprographyPoint = [[MKPointAnnotation alloc] init];
    reprographyPoint.coordinate = CLLocationCoordinate2DMake(39.482146,-0.348827);
    reprographyPoint.title = NSLocalizedString(@"Reprography",@"");
    reprographyPoint.subtitle = NSLocalizedString(@"Building 1B",@"");
    [EtsinfMapView addAnnotation:reprographyPoint];
    
    MKPointAnnotation *secretaryPoint = [[MKPointAnnotation alloc] init];
    secretaryPoint.coordinate = CLLocationCoordinate2DMake(39.482808,-0.3471);
    secretaryPoint.title = NSLocalizedString(@"Secretary",@"");
    secretaryPoint.subtitle = NSLocalizedString(@"Building 1G",@"");
    [EtsinfMapView addAnnotation:secretaryPoint];
    
    MKPointAnnotation *DSICPoint = [[MKPointAnnotation alloc] init];
    DSICPoint.coordinate = CLLocationCoordinate2DMake(39.482419,-0.347041);
    DSICPoint.title = NSLocalizedString(@"DSIC",@"");
    DSICPoint.subtitle = NSLocalizedString(@"Building 1F",@"");
    [EtsinfMapView addAnnotation:DSICPoint];
    
    MKPointAnnotation *DAIPoint = [[MKPointAnnotation alloc] init];
    DAIPoint.coordinate = CLLocationCoordinate2DMake(39.482734,-0.347358);
    DAIPoint.title = NSLocalizedString(@"DAI",@"");
    DAIPoint.subtitle = NSLocalizedString(@"Building 1H",@"");
    [EtsinfMapView addAnnotation:DAIPoint];
    
    MKPointAnnotation *freeComputerRoomPoint = [[MKPointAnnotation alloc] init];
    freeComputerRoomPoint.coordinate = CLLocationCoordinate2DMake(39.482564,-0.34761);
    freeComputerRoomPoint.title = NSLocalizedString(@"Free access computer room",@"");
    freeComputerRoomPoint.subtitle = NSLocalizedString(@"Building 1B",@"");
    [EtsinfMapView addAnnotation:freeComputerRoomPoint];
    
    MKPointAnnotation *dsicLabs = [[MKPointAnnotation alloc] init];
    dsicLabs.coordinate = CLLocationCoordinate2DMake(39.482614,-0.347873);
    dsicLabs.title = NSLocalizedString(@"DSIC Labs",@"");
    dsicLabs.subtitle = NSLocalizedString(@"Building 1B",@"");
    [EtsinfMapView addAnnotation:dsicLabs];
    
    MKPointAnnotation *discaLabs = [[MKPointAnnotation alloc] init];
    discaLabs.coordinate = CLLocationCoordinate2DMake(39.482634,-0.346542);
    discaLabs.title = NSLocalizedString(@"DISCA Labs",@"");
    discaLabs.subtitle = NSLocalizedString(@"Building 1G, 2nd floor",@"");
    [EtsinfMapView addAnnotation:discaLabs];
}

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self)
    {
//        [[self tabBarItem] setTitle:@"Map"];
        [[self tabBarItem] setImage:[UIImage imageNamed:@"world.png"]];
        locationManager = [[CLLocationManager alloc] init];
        [locationManager setDelegate:self];
        [locationManager setDesiredAccuracy:kCLLocationAccuracyBest];
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    [EtsinfMapView setShowsUserLocation:YES];
    CLLocationCoordinate2D coordETSINF = CLLocationCoordinate2DMake(39.482344,-0.347724);
    MKCoordinateRegion region = MKCoordinateRegionMakeWithDistance(coordETSINF, 225, 225);
    [EtsinfMapView setRegion:region animated:YES];
    
    [self makeMapAnnotations];
    
    NSInteger mapTypeValue = [[NSUserDefaults standardUserDefaults] integerForKey:etsinfUpvMapTypePrefKey];
    [mapTypeControl setSelectedSegmentIndex:mapTypeValue];
    [self changeMapType:mapTypeControl];
    
    NSInteger mapRegionValue = [[NSUserDefaults standardUserDefaults] integerForKey:etsinfUpvMapRegionPrefKey];
    [mapRegionControl setSelectedSegmentIndex:mapRegionValue];
    [self changeMapRegion:mapRegionControl];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)locationManager:(CLLocationManager *)manager didFailWithError:(NSError *)error
{
    //Alerta avisando de no conexión
    
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:NSLocalizedString(@"Failure",@"")
                                                    message:NSLocalizedString(@"Your device doesn't have internet access",@"")
                                                   delegate:nil
                                          cancelButtonTitle:@"OK"
                                          otherButtonTitles:nil];
    [alert show];
}

- (void)locationManager:(CLLocationManager *)manager didUpdateLocations:(NSArray *)locations
{
    /*for (int i = 0; i < [locations count]; i++) {
        NSLog(@"*****LOCATION %d*****\n%@", i, [locations objectAtIndex:i]);
    }*/
}

- (IBAction)changeMapType:(id)sender
{
    [[NSUserDefaults standardUserDefaults] setInteger:[sender selectedSegmentIndex] forKey:etsinfUpvMapTypePrefKey];
    switch ([sender selectedSegmentIndex]) {
        case 0:
        {
            [EtsinfMapView setMapType:MKMapTypeStandard];
            break;
        }
        case 1:
        {
            [EtsinfMapView setMapType:MKMapTypeSatellite];
            break;
        }
        case 2:
        {
            [EtsinfMapView setMapType:MKMapTypeHybrid];
            break;
        }
        default:
            break;
    }
}

- (IBAction)changeMapRegion:(id)sender
{
    [[NSUserDefaults standardUserDefaults] setInteger:[sender selectedSegmentIndex] forKey:etsinfUpvMapRegionPrefKey];
    switch ([sender selectedSegmentIndex]) {
        case 0:
        {
            //Coordinates ETSINF
            CLLocationCoordinate2D coordETSINF = CLLocationCoordinate2DMake(39.482344,-0.347724);
            MKCoordinateRegion regionETSINF = MKCoordinateRegionMakeWithDistance(coordETSINF , 225, 225);
            [EtsinfMapView setRegion:regionETSINF animated:YES];
            break;
        }
        case 1:
        {
            //Coordinates Valencia
            CLLocationCoordinate2D coordValencia = CLLocationCoordinate2DMake(39.468535,-0.376389);
            MKCoordinateRegion regionValencia = MKCoordinateRegionMakeWithDistance(coordValencia, 10000, 10000);
            [EtsinfMapView setRegion:regionValencia animated:YES];
            break;
        }
        default:
            break;
    }
}

- (void)dealloc
{
    [locationManager setDelegate:nil];
}

@end
